@@ -2,6 +2,8 @@ package Parley::Controller::Post;
 
 use strict;
 use warnings;
+
+use Parley::Version;  our $VERSION = $Parley::VERSION;
 use base 'Catalyst::Controller';
 use DateTime;
 use JSON;
@@ -15,6 +17,7 @@ my %dfv_profile_for = (
     # DFV validation profile for adding a new topic
     edit_post => {
         required    => [qw( post_message )],
+        optional    => [qw( lock_post )],
         filters     => [qw( trim )],
         msgs => {
             format  => q{%s},
@@ -41,15 +44,34 @@ sub edit : Local {
     # what people will make-up or bookmark)
     $c->login_if_required($c->localize(q{EDIT LOGIN REQUIRED}));
 
+    # deal with posting banned by IP
+    my $ip = $c->request->address;
+    my $posting_banned =
+        $c->model('ParleyDB::IpBan')->is_posting_banned($ip);
+    if ($posting_banned) {
+        $c->stash->{template} = 'user/posting_ip_banned';
+        return;
+    }
+
     # you can only edit you own posts
-    # (unless you're a moderator, but we don't do that yet)
-    if ($c->_authed_user()->id() != $c->_current_post()->creator()->id()) {
+    # (unless you're a moderator)
+    if (
+        (not $c->stash->{moderator})
+            and
+        ($c->_authed_user()->id() != $c->_current_post()->creator()->id())
+    ) {
         $c->stash->{error}{message} = $c->localize(q{EDIT OWN POSTS ONLY});
         return;
     }
 
-    # you can't edit a locked post
-    elsif ($c->_current_post->thread->locked) {
+    # you can't edit post in a locked thread
+    # you also can't edit individually locked posts (unless you are a
+    # moderator)
+    elsif (
+        $c->_current_post->thread->locked
+            or
+        ($c->_current_post->locked and not $c->stash->{moderator})
+    ) {
         $c->stash->{error}{message} = $c->localize(q{EDIT LOCKED POST});
         return;
     }
@@ -74,6 +96,7 @@ sub edit : Local {
             }
         }
         # otherwise; everything seems fine - edit the post
+        # XXX why the HELL isn't this in a txn_do?!
         else {
             # update the post with the new information
             $c->_current_post->message( $c->form->valid->{post_message} );
@@ -81,6 +104,23 @@ sub edit : Local {
             # set the edited time
             $c->_current_post->edited( DateTime->now() );
 
+            # did an 'evil' admin edit the post?
+            if (
+                ($c->_current_post->creator_id != $c->_authed_user->id)
+                    and
+                $c->stash->{moderator}
+            ) {
+                # stamp the post with the admin editor's mark
+                $c->_current_post->admin_editor_id(
+                    $c->_authed_user->id
+                );
+                # if they asked for the thread to be locked
+                # make it so...
+                if ($c->form->valid->{lock_post}) {
+                    $c->_current_post->locked( 1 );
+                }
+            }
+
             # store the updates in the db
             $c->_current_post->update();
 
@@ -127,16 +167,16 @@ sub view : Local {
 sub preview : Local {
     my ($self, $c) = @_;
     my $tt_forum = Template::Plugin::ForumCode->new();
+    my $msg_source = $c->request->param('msg_source');
 
-    my $json = objToJson(
+    my $json = to_json(
         {
             'formatted' =>
                 $tt_forum->forumcode(
-                    $c->request->param('msg_source')
+                    $msg_source
                 )
         }
     );
-    #$c->log->debug( $json );
 
     $c->response->body( $json );
     return;
