@@ -5,6 +5,9 @@ package Parley::Schema::Thread;
 use strict;
 use warnings;
 
+use Parley::Version;  our $VERSION = $Parley::VERSION;
+use DateTime::Format::Pg;
+
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components("PK::Auto", "Core");
@@ -12,7 +15,7 @@ __PACKAGE__->table("thread");
 __PACKAGE__->add_columns(
   "id" => {
     data_type => "integer",
-    default_value => "nextval('thread_thread_id_seq'::regclass)",
+    #default_value => "nextval('thread_thread_id_seq'::regclass)",
     is_nullable => 0,
     size => 4,
   },
